pub unsafe extern "C" fn dds_delete(
entity: dds_entity_t,
) -> dds_return_tExpand description
@brief Delete given entity. @ingroup entity @component generic_entity
This operation will delete the given entity. It will also automatically delete all its children, childrens’ children, etc entities.
Some parent entities are created implicitly by the API. A domain can be created implicitly by @ref dds_create_participant. A publisher or subscriber can be created implicitly by @ref dds_create_writer or @ref dds_create_reader when called with a participant and a normal topic. Such implicit entities are deleted automatically when their last child is deleted. They are also deleted as part of the recursive deletion of one of their ancestors. Explicitly created domains, publishers and subscribers are not deleted merely because they have no children; they must be deleted explicitly, or by deleting an ancestor that contains them.
@param[in] entity Entity to delete.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK The entity and its children (recursive are deleted). @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.