dds_dynamic_member_set_try_construct

Function dds_dynamic_member_set_try_construct 

pub unsafe extern "C" fn dds_dynamic_member_set_try_construct(
    type_: *mut dds_dynamic_type_t,
    member_id: u32,
    try_construct: dds_dynamic_type_try_construct,
) -> dds_return_t
@brief Set the try_construct mode for a Dynamic Type member @ingroup dynamic_type @component dynamic_type_api

@param[in,out] type Dynamic Type that contains the member to set the must-understand flag for (must be a structure type). @param[in] member_id The ID of the member to set the flag for. @param[in] try_construct Indicates whether the must-understand flag should be set or cleared.

@return dds_return_t Return code. In case of an error, the return code field in the provided type is also set to this value.

@retval DDS_RETCODE_OK The flag is updated successfully. @retval DDS_RETCODE_BAD_PARAMETER One or more of the provided parameters are invalid. @retval DDS_RETCODE_PRECONDITION_NOT_MET The provided type is not in the CONSTRUCTING state.