dds_dynamic_type_create

Function dds_dynamic_type_create 

pub unsafe extern "C" fn dds_dynamic_type_create(
    entity: dds_entity_t,
    descriptor: dds_dynamic_type_descriptor_t,
) -> dds_dynamic_type_t
@brief Create a new Dynamic Type @ingroup dynamic_type @component dynamic_type_api

Creates a new Dynamic Type, using the properties that are set in the type descriptor. In case these properties include a base-type, element-type or discriminator type, the ownership of these types is transferred to the newly created type.

@param[in] entity A DDS entity (any entity, except the pseudo root entity identified by DDS_CYCLONEDDS_HANDLE). This entity is used to get the type library of the entity’s domain, to add the type to. @param[in] descriptor The Dynamic Type descriptor.

@return dds_dynamic_type_t A Dynamic Type reference for the created type.

@retval DDS_RETCODE_OK The type is created successfully. @retval DDS_RETCODE_BAD_PARAMETER One or more of the provided parameters are invalid. @retval DDS_RETCODE_UNSUPPORTED The provided type kind is not supported. @retval DDS_RETCODE_OUT_OF_RESOURCES Not enough resources to create the type.