pub unsafe extern "C" fn dds_dynamic_type_register(
type_: *mut dds_dynamic_type_t,
type_info: *mut *mut ddsi_typeinfo,
) -> dds_return_tExpand description
@brief Registers a Dynamic Type @ingroup dynamic_type @component dynamic_type_api
This function registers a dynamic type, making it immutable and finalizing its definition. A type that is registered, get the state ‘RESOLVED’ and is stored in the type library.
@param[in] type A pointer to the dynamic type to be registered. @param[out] type_info A pointer to a pointer to a ddsi_typeinfo structure that holds information about the registered type.
@return dds_return_t Return code.
@retval DDS_RETCODE_OK The type was successfully registered. @retval DDS_RETCODE_BAD_PARAMETER One or more of the provided parameters are invalid. @retval DDS_RETCODE_PRECONDITION_NOT_MET The provided type is not in the CONSTRUCTING state. @retval DDS_RETCODE_OUT_OF_RESOURCES Not enough resources to create the type.