pub unsafe extern "C" fn dds_dynamic_type_unref(
type_: *mut dds_dynamic_type_t,
) -> dds_return_tExpand description
@brief Unref a Dynamic Type
@param type The Dynamic Type to dereference.
@return dds_return_t Return code.
@retval DDS_RETCODE_OK The type was successfully registered. @retval DDS_RETCODE_BAD_PARAMETER One or more of the provided parameters are invalid. @retval DDS_RETCODE_PRECONDITION_NOT_MET The provided type is not in the CONSTRUCTING state.