pub unsafe extern "C" fn dds_get_entity_sertype(
entity: dds_entity_t,
sertype: *mut *const ddsi_sertype,
) -> dds_return_tExpand description
@brief Gets the sertype of an entity
The provided entity must be a topic or endpoint. This function returns a pointer to the sertype of the entity. The refcount of the sertype is not incremented. The lifetime of the returned sertype pointer is at least that of the lifetime of the entity on which it was invoked.
@param[in] entity A topic, reader or writer entity @param[out] sertype A pointer to the entity’s sertype is stored in this parameter (see note above on lifetime of this pointer)
@returns A dds_return_t indicating success or failure. @retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER The sertype parameter is NULL @retval DDS_RETCODE_ILLEGAL_OPERATION Not a topic, reader or writer entity