pub unsafe extern "C" fn dds_get_subscriber(
entity: dds_entity_t,
) -> dds_entity_tExpand description
@brief Get entity subscriber. @ingroup entity @component entity_relations
This operation returns the subscriber to which the given entity belongs. For instance, it will return the Subscriber that was used when creating a DataReader (when that DataReader was provided here). If the reader was created directly on a participant and a normal topic, this returns the implicit subscriber that was created as the reader’s parent. If the reader is for a built-in topic, this returns the participant’s built-in subscriber.
@param[in] entity Entity from which to get its subscriber.
@returns A valid subscriber handle or an error code.
@retval >0 A valid subscriber handle. @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted. DOC_TODO: Link to generic dds entity relations documentation.