dds_get_type_name

Function dds_get_type_name 

pub unsafe extern "C" fn dds_get_type_name(
    topic: dds_entity_t,
    name: *mut c_char,
    size: usize,
) -> dds_return_t
@brief Returns the type name of a given topic. @ingroup topic @component topic

@param[in] topic The topic. @param[out] name Buffer to write the topic type name to. @param[in] size Number of bytes available in the buffer.

@returns A dds_return_t indicating success or failure.

@return Actual length of type name (name is truncated if return value >= size) or error