dds_get_typeinfo

Function dds_get_typeinfo 

pub unsafe extern "C" fn dds_get_typeinfo(
    entity: dds_entity_t,
    type_info: *mut *mut dds_typeinfo_t,
) -> dds_return_t
@brief This function gets the type information from the provided topic, reader or writer @ingroup xtypes @component type_metadata

@param[in] entity A topic/reader/writer entity @param[out] type_info The type information, untouched if returncode indicates failure

@returns A dds_return_t indicating success or failure.

@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER The type_info parameter is null @retval DDS_RETCODE_NOT_FOUND The entity does not have type information set @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_UNSUPPORTED Cyclone DDS built without type discovery (cf. DDS_HAS_TYPELIB)