pub unsafe extern "C" fn dds_log_cfg_init(
cfg: *mut ddsrt_log_cfg,
domid: u32,
tracemask: u32,
log_fp: *mut FILE,
trace_fp: *mut FILE,
)Expand description
@brief Initialize a struct ddsrt_log_cfg for use with dds_log_cfg
Callbacks registered to handle log messages will receive messages of type info, warning, error and fatal. Messages that fall into the trace category will never be delivered to the callback.
Callbacks registered to handle trace messages will receive messages of type info, warning, error and fatal as well as all message types that fall into the trace category depending on the log mask.
This operation is synchronous and only returns once the operation is registered with all threads. Meaning that neither callback or userdata will be referenced by the DDS stack on return.
@param[out] cfg On return, initialised to make dds_log_cfg invoked with this config object behave as specified by the other parameters. @param[in] domid Numerical identifier in log/trace, UINT32_MAX is reserved for global logging. @param[in] tracemask Mask determining which traces should be written. @param[in] log_fp File for default sink. @param[in] trace_fp File for default sink.