dds_log_id

Function dds_log_id 

pub unsafe extern "C" fn dds_log_id(
    cat: u32,
    domid: u32,
    file: *const c_char,
    line: u32,
    func: *const c_char,
    fmt: *const c_char,
    ...
)
@brief Write a log or trace message to the global configuration but with specific domain (intended solely for use during domain start-up, while the domain-specific logging/tracing hasn’t been set yet).

Write a log or trace message to one (or both) of the currently active sinks.

Direct use of #dds_log_id is discouraged. Use #DDS_ILOG instead.