dds_lset_sample_lost_arg

Function dds_lset_sample_lost_arg 

pub unsafe extern "C" fn dds_lset_sample_lost_arg(
    listener: *mut dds_listener_t,
    callback: dds_on_sample_lost_fn,
    arg: *mut c_void,
    reset_on_invoke: bool,
) -> dds_return_t
@ingroup listener_setters @component listener_obj @brief Set the sample_lost callback and argument in the listener structure.

@param[in,out] listener listener structure to update @param[in] callback the callback to set or a null pointer @param[in] arg callback argument that is passed uninterpreted to the callback function @param[in] reset_on_invoke whether or not the status should be cleared when the listener callback is invoked

@retval DDS_RETCODE_OK success @retval DDS_RETCODE_BAD_PARAMETER listener is a null pointer