dds_qget_reliability

Function dds_qget_reliability 

pub unsafe extern "C" fn dds_qget_reliability(
    qos: *const dds_qos_t,
    kind: *mut dds_reliability_kind_t,
    max_blocking_time: *mut dds_duration_t,
) -> bool
@ingroup qos_getters @component qos_obj @brief Get the reliability qos policy

@param[in] qos - Pointer to a dds_qos_t structure storing the policy @param[in,out] kind - Pointer that will store the reliability kind (optional) @param[in,out] max_blocking_time - Pointer that will store the max blocking time for reliable reliability (optional)

@returns - false iff any of the arguments is invalid or the qos is not present in the qos object