pub unsafe extern "C" fn dds_stream_writeLE(
os: *mut dds_ostreamLE_t,
allocator: *const dds_cdrstream_allocator,
data: *const c_char,
ops: *const u32,
) -> *const u32Expand description
@brief Serialize data using little-endian byte order. @component cdr_serializer
@param os little-endian output stream to append to @param allocator allocator used to grow the stream @param data sample or key data to serialize @param ops marshalling metadata for @p data @returns pointer to the next operation on success, NULL on failure