dds_stream_write_key

Function dds_stream_write_key 

pub unsafe extern "C" fn dds_stream_write_key(
    os: *mut dds_ostream_t,
    ser_kind: dds_cdr_key_serialization_kind,
    allocator: *const dds_cdrstream_allocator,
    sample: *const c_char,
    desc: *const dds_cdrstream_desc,
) -> bool
@brief Serialize the key fields from a sample using native byte order. @component cdr_serializer

@param os output stream to append to @param ser_kind key serialization kind to produce @param allocator allocator used to grow the stream @param sample sample containing the key fields @param desc CDR stream descriptor for the sample type @returns true on success, false on serialization failure