pub unsafe extern "C" fn dds_stream_write_keyBE(
os: *mut dds_ostreamBE_t,
ser_kind: dds_cdr_key_serialization_kind,
allocator: *const dds_cdrstream_allocator,
sample: *const c_char,
desc: *const dds_cdrstream_desc,
) -> boolExpand description
@brief Serialize the key fields from a sample using big-endian byte order. @component cdr_serializer
@param os big-endian output stream to append to @param ser_kind key serialization kind to produce @param allocator allocator used to grow the stream @param sample sample containing the key fields @param desc CDR stream descriptor for the sample type @returns true on success, false on serialization failure