dds_stream_write_with_midLE

Function dds_stream_write_with_midLE 

pub unsafe extern "C" fn dds_stream_write_with_midLE(
    os: *mut dds_ostreamLE_t,
    allocator: *const dds_cdrstream_allocator,
    mid_table: *const dds_cdrstream_desc_mid_table,
    data: *const c_char,
    ops: *const u32,
) -> *const u32
@brief Serialize data using little-endian byte order and a member-id table. @component cdr_serializer

@param os little-endian output stream to append to @param allocator allocator used to grow the stream @param mid_table member-id table for non-mutable member headers, or NULL @param data sample or key data to serialize @param ops marshalling metadata for @p data @returns pointer to the next operation on success, NULL on failure