ddsrt_avl_swap_node

Function ddsrt_avl_swap_node 

pub unsafe extern "C" fn ddsrt_avl_swap_node(
    td: *const ddsrt_avl_treedef_t,
    tree: *mut ddsrt_avl_tree_t,
    voldn: *mut c_void,
    vnewn: *mut c_void,
)
@brief Replace a node in the tree.

Replace a node in the tree without using @ref ddsrt_avl_delete and @ref ddsrt_avl_insert. This operation can invalidate the tree as it doesn’t check whether the key of the new node preserves the ordering of the set.

@param[in] td treedef of the tree @param[in,out] tree the avl tree @param[in] voldn the node to replace @param[in] vnewn the node to take the old node’s place @see ddsrt_avl_insert @see ddsrt_avl_delete