ddsrt_getsockopt

Function ddsrt_getsockopt 

pub unsafe extern "C" fn ddsrt_getsockopt(
    sock: ddsrt_socket_t,
    level: i32,
    optname: i32,
    optval: *mut c_void,
    optlen: *mut socklen_t,
) -> dds_return_t
@brief Get options from the socket.

Argument ‘optlen’ is a value-result argument, initially containing the size of the buffer pointed to by ‘optval’, and modified on return to indicate the actual size of the value returned.

@param[in] sock the socket @param[in] level the level at which the option resides. For socket API use SOL_SOCKET @param[in] optname the name of the option (SO_REUSEADDR, SO_DONTROUTE, SO_BROADCAST, SO_SNDBUF, SO_RCVBUF, …) @param[out] optval buffer into which to receive the option value @param[in,out] optlen size of buffer ‘optval’ @return a DDS_RETCODE (OK, ERROR, BAD_PARAMETER, UNSUPPORTED)

See @ref ddsrt_setsockopt