pub unsafe extern "C" fn ddsrt_gettid_for_thread(
thread: ddsrt_thread_t,
) -> ddsrt_tid_tExpand description
@brief Retrieve integer representation of the given thread id.
@returns The integer representation of the given thread.
pub unsafe extern "C" fn ddsrt_gettid_for_thread(
thread: ddsrt_thread_t,
) -> ddsrt_tid_t@brief Retrieve integer representation of the given thread id.
@returns The integer representation of the given thread.