pub unsafe extern "C" fn ddsrt_hh_enum(
rt: *mut ddsrt_hh,
f: Option<unsafe extern "C" fn(a: *mut c_void, f_arg: *mut c_void)>,
f_arg: *mut c_void,
)Expand description
@brief Walk the hash table and apply a user defined function to each node.
The walk function ‘f’ receives in parameter ‘a’ the pointer to user data, and has ‘f_arg’ as an optional extra argument. It is allowed to modify the user data. The @ref ddsrt_hh_enum is useful to free user data (by passing a function ‘f’ that frees memory pointed to by ‘a’) prior to calling @ref ddsrt_hh_free.
@param[in,out] rt the hash table @param[in] f user defined walk function to apply to each element @param[in] f_arg extra argument for walk function @see ddsrt_hh_iter_next