ddsrt_hh_remove

Function ddsrt_hh_remove 

pub unsafe extern "C" fn ddsrt_hh_remove(
    rt: *mut ddsrt_hh,
    keyobject: *const c_void,
) -> bool
@brief Remove an element from the hash table.

It only uses the key of the passed object and as such it will also work if you pass a dummy object. However, you still need to free the memory of the object after removing it from the hash table. Since this means you need to have the pointer to the actual object anyway, you might as well use that.

@param[in,out] rt the hash table @param[in] keyobject user data to remove @return false iff key not present @see ddsrt_hh_add