pub unsafe extern "C" fn ddsrt_recvmsg(
sockext: *const ddsrt_socket_ext_t,
msg: *mut ddsrt_msghdr_t,
flags: c_int,
rcvd: *mut usize,
) -> dds_return_tExpand description
@brief Receive a message
- If a message is too long to fit in the supplied buffer, excess bytes may be discarded depending on the type of socket the message is received from.
- If no data is available at the socket, the call waits for a message to arrive, unless the socket is nonblocking (MSG_DONTWAIT).
- The ‘flags’ can be 0, or the bitwise OR of one or more of: {MSG_CMSG_CLOEXEC, MSG_DONTWAIT, MSG_ERRQUEUE, MSG_OOB, MSG_PEEK, MSG_TRUNC, MSG_WAITALL}
@param[in] sockext the socket @param[out] msg the message received @param[in] flags flags for special options @param[out] rcvd number of bytes received (>= 0 if return == OK, undefined if return != OK) @return a DDS_RETCODE (OK, ERROR, TRY_AGAIN, BAD_PARAMETER, NO_CONNECTION, INTERRUPTED, OUT_OF_RESOURCES, ILLEGAL_OPERATION)
See @ref ddsrt_sendmsg