pub unsafe extern "C" fn ddsrt_sockaddr_isloopback(
sa: *const sockaddr,
) -> boolExpand description
@brief Check if the given address is a loopback address.
@param[in] sa Socket address to check.
@return true if the address is a loopback address, false otherwise.