ddsrt_thread_cleanup_push

Function ddsrt_thread_cleanup_push 

pub unsafe extern "C" fn ddsrt_thread_cleanup_push(
    routine: Option<unsafe extern "C" fn(p: *mut c_void)>,
    arg: *mut c_void,
) -> dds_return_t
@brief Push cleanup handler onto the cleanup stack

Push a cleanup handler onto the top of the calling thread’s cleanup stack. The cleanup handler will be popped of the thread’s cleanup stack and invoked with the specified argument when the thread exits.

@param[in] routine Cleanup handler to push onto the thread cleanup stack. @param[in] arg Argument that will be passed to the cleanup handler.