ddsrt_thread_fini

Function ddsrt_thread_fini 

pub unsafe extern "C" fn ddsrt_thread_fini(reason: u32)
@brief Free thread resources and execute cleanup handlers.

Platforms that support it, automatically free resources claimed by the current thread and call any registered cleanup routines. This function only needs to be called on platforms that do not support thread destructors and only for threads that were not created with @ddsrt_thread_create.