pub unsafe extern "C" fn ddsrt_thread_getname_anythread(
tid: ddsrt_thread_list_id_t,
name: *mut c_char,
size: usize,
) -> dds_return_tExpand description
@brief Get the name of the specified thread (in the calling process)
@param[in] tid Thread identifier for which the name is sought @param[out] name Filled with the thread name (or a synthesized one) on successful return; name is silently truncated if the actual name is longer than name can hold; always 0-terminated if size > 0 @param[in] size Number of bytes of name that may be assigned, size is 0 is allowed, though somewhat useless
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK Possibly truncated name is returned as a null-terminated string in name (provided size > 0). @retval DDS_RETCODE_NOT_FOUND Thread not found; the contents of name is unchanged @retval DDS_RETCODE_ERROR Unspecified failure, the contents of name is undefined @retval DDS_RETCODE_UNSUPPORTED Not supported on the platform