ddsrt_time_elapsed

Function ddsrt_time_elapsed 

pub unsafe extern "C" fn ddsrt_time_elapsed() -> ddsrt_etime_t
@brief Get elapsed (and thus monotonic) time since some fixed unspecified past time.

The elapsed time clock is a clock with near real-time progression and can be used when a high-resolution suspend-aware monotonic clock is needed, without having to deal with the complications of discontinuities if for example the time is changed. The fixed point from which the elapsed time is returned is not guaranteed to be fixed over reboots of the system.

@returns Elapsed time if available, otherwise return monotonic time.