pub unsafe extern "C" fn ddsrt_time_wallclock() -> ddsrt_wctime_tExpand description
@brief Get the current time in nanoseconds since the UNIX Epoch. Identical to (ddsrt_wctime_t){dds_time()}
@returns Current time.
pub unsafe extern "C" fn ddsrt_time_wallclock() -> ddsrt_wctime_t@brief Get the current time in nanoseconds since the UNIX Epoch. Identical to (ddsrt_wctime_t){dds_time()}
@returns Current time.