#[repr(C)]pub struct ddsrt_avl_tree {
pub root: *mut ddsrt_avl_node_t,
}Expand description
@brief The avl tree.
The tree only knows the root @ref ddsrt_avl_node. The settings for the tree are stored separately in the @ref ddsrt_avl_treedef. As a result, most tree operations require you to provide both the treedef and the tree.
Fields
root: *mut ddsrt_avl_node_t< is the root node of the tree