#[repr(C)]pub struct ddsrt_avl_treedef {
pub avlnodeoffset: usize,
pub keyoffset: usize,
pub u: ddsrt_avl_treedef__bindgen_ty_1,
pub augment: ddsrt_avl_augment_t,
pub flags: u32,
pub cmp_arg: *mut c_void,
}Expand description
@brief The tree definition.
The treedef stores settings for the tree, but does not hold the actual tree itself. This implies that:
- A single treedef can be used for multiple trees of the same type.
- Most tree operations require you to provide both the treedef and the @ref ddsrt_avl_tree.
To initialize it, use @ref ddsrt_avl_treedef_init, @ref ddsrt_avl_treedef_init_r, or one of the ‘DDSRT_AVL_TREEDEF_INITIALIZER’ macros.
Fields
avlnodeoffset: usizekeyoffset: usizeu: ddsrt_avl_treedef__bindgen_ty_1augment: ddsrt_avl_augment_tflags: u32cmp_arg: *mut c_voidTrait Implementations
Sourceimpl Clone for ddsrt_avl_treedef
impl Clone for ddsrt_avl_treedef
Sourcefn clone(&self) -> ddsrt_avl_treedef
fn clone(&self) -> ddsrt_avl_treedef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ddsrt_avl_treedef
Sourceimpl Debug for ddsrt_avl_treedef
impl Debug for ddsrt_avl_treedef