#[repr(C)]pub struct ddsrt_log_cfg_common {
pub mask: u32,
pub tracemask: u32,
pub domid: u32,
}Expand description
Semi-opaque type for log/trace configuration.
Fields
mask: u32Mask for testing whether the xLOG macro should forward to the function (and so incur the cost of constructing the parameters). Messages in DDS_LOG_MASK are rare, so the overhead of calling the function and then dropping the message is not an issue, unlike for messages in DDS_TRACE_MASK.
tracemask: u32The actual configured trace mask
domid: u32Domain id for reporting; UINT32_MAX = no domain