dds_dynamic_type_t

Type Alias dds_dynamic_type_t 

pub type dds_dynamic_type_t = dds_dynamic_type;
@brief Dynamic Type @ingroup dynamic_type

Representation of a dynamically created type. This struct has an opaque pointer to the type in the type system. During construction of the type (setting properties and adding members), the internal type has the state ‘CONSTRUCTION’. Once the type is registered, the state is updated to ‘RESOLVED’ and the type cannot be modified.

The ‘ret’ member of this struct holds the return code of operations performed on this type. In case this value is not DDS_RETCODE_OK, the type cannot be used for further processing (e.g. adding members, registering the type, etc.).

Aliased Type

#[repr(C)]
pub struct dds_dynamic_type_t { pub x: [*mut c_void; 2], pub ret: i32, }

Fields

x: [*mut c_void; 2]ret: i32