dds_sample_info_t

Type Alias dds_sample_info_t 

pub type dds_sample_info_t = dds_sample_info;
Contains information about the associated data value

Aliased Type

#[repr(C)]
pub struct dds_sample_info_t { pub sample_state: u32, pub view_state: u32, pub instance_state: u32, pub valid_data: bool, pub source_timestamp: i64, pub instance_handle: u64, pub publication_handle: u64, pub disposed_generation_count: u32, pub no_writers_generation_count: u32, pub sample_rank: u32, pub generation_rank: u32, pub absolute_generation_rank: u32, }

Fields

sample_state: u32

Sample state

view_state: u32

View state

instance_state: u32

Instance state

valid_data: bool

Indicates whether there is a data associated with a sample

  • true, indicates the data is valid
  • false, indicates the data is invalid, no data to read
source_timestamp: i64

timestamp of a data instance when it is written

instance_handle: u64

handle to the data instance

publication_handle: u64

handle to the publisher

disposed_generation_count: u32

count of instance state change from NOT_ALIVE_DISPOSED to ALIVE

no_writers_generation_count: u32

count of instance state change from NOT_ALIVE_NO_WRITERS to ALIVE

sample_rank: u32

indicates the number of samples of the same instance that follow the current one in the collection

generation_rank: u32

difference in generations between the sample and most recent sample of the same instance that appears in the returned collection

absolute_generation_rank: u32

difference in generations between the sample and most recent sample of the same instance when read/take was called