ddsrt_avl_tree_t

Type Alias ddsrt_avl_tree_t 

pub type ddsrt_avl_tree_t = ddsrt_avl_tree;
@brief The avl tree.

The tree only knows the root @ref ddsrt_avl_node. The settings for the tree are stored separately in the @ref ddsrt_avl_treedef. As a result, most tree operations require you to provide both the treedef and the tree.

Aliased Type

#[repr(C)]
pub struct ddsrt_avl_tree_t { pub root: *mut ddsrt_avl_node, }

Fields

root: *mut ddsrt_avl_node

< is the root node of the tree