ddsrt_hh_equals_fn

Type Alias ddsrt_hh_equals_fn 

pub type ddsrt_hh_equals_fn = Option<unsafe extern "C" fn(a: *const c_void, b: *const c_void) -> bool>;
@brief User defined equals function.

Hopscotch needs to be able to compare two elements to confirm it has found the correct one (equal hashes doesn’t guarantee that the keys are equal). The input arguments are pointers to the user data objects to compare. Returns int meant to be interpreted as bool (1 is match, 0 is no match)

Aliased Type

pub enum ddsrt_hh_equals_fn {
    None,
    Some(unsafe extern "C" fn(*const c_void, *const c_void) -> bool),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const c_void, *const c_void) -> bool)

Some value of type T.