pub unsafe extern "C" fn dds_ostream_init(
os: *mut dds_ostream_t,
allocator: *const dds_cdrstream_allocator,
size: u32,
xcdr_version: dds_cdr_enc_version,
)Expand description
@brief Initialize a native-endian output CDR stream. @component cdr_serializer
Allocates an initial buffer of @p size bytes, or leaves the buffer NULL when @p size is zero. The stream owns the allocated buffer until finalized and serializes using native endianness.
@param os output stream to initialize @param allocator allocator used for stream storage @param size initial stream buffer size in bytes @param xcdr_version XCDR version to use when serializing