pub unsafe extern "C" fn dds_qget_presentation(
qos: *const dds_qos_t,
access_scope: *mut dds_presentation_access_scope_kind_t,
coherent_access: *mut bool,
ordered_access: *mut bool,
) -> boolExpand description
@ingroup qos_getters @component qos_obj @brief Get the presentation policy from a qos structure
@param[in] qos - Pointer to a dds_qos_t structure storing the policy @param[in,out] access_scope - Pointer that will store access scope kind (optional) @param[in,out] coherent_access - Pointer that will store coherent access enable value (optional) @param[in,out] ordered_access - Pointer that will store orderede access enable value (optional)
@returns - false iff any of the arguments is invalid or the qos is not present in the qos object