pub unsafe extern "C" fn dds_sleepfor(reltime: dds_duration_t)Expand description
@brief Suspend execution of calling thread until relative time n elapsed.
Execution is suspended for n nanoseconds. Should the call be interrupted, the call is re-entered with the remaining time.
@param[in] reltime Relative time in nanoseconds.