pub unsafe extern "C" fn dds_stream_free_sample(
data: *mut c_void,
allocator: *const dds_cdrstream_allocator,
ops: *const u32,
)Expand description
@brief Release dynamically allocated members in a deserialized sample. @component cdr_serializer
Frees strings, sequences, external members and nested allocated data described by @p ops. The sample storage itself remains owned by the caller.
@param data sample storage to clean up @param allocator allocator used for allocated sample members @param ops marshalling metadata for @p data