dds_stream_read

Function dds_stream_read 

pub unsafe extern "C" fn dds_stream_read(
    is: *mut dds_istream_t,
    data: *mut c_char,
    allocator: *const dds_cdrstream_allocator,
    ops: *const u32,
) -> *const u32
@brief Deserialize data according to stream operations. @component cdr_serializer

@param is input stream containing serialized data @param data destination storage for deserialized data @param allocator allocator used for dynamically allocated members @param ops marshalling metadata for the data type @returns pointer to the next operation after the data that was read