pub unsafe extern "C" fn dds_stream_write_with_byte_order(
os: *mut dds_ostream_t,
allocator: *const dds_cdrstream_allocator,
mid_table: *const dds_cdrstream_desc_mid_table,
data: *const c_char,
ops: *const u32,
bo: ddsrt_byte_order_selector,
) -> *const u32Expand description
@brief Serialize data using a selected byte order. @component cdr_serializer
Dispatches to the native, little-endian, or big-endian writer according to @p bo.
@param os output stream to append to @param allocator allocator used to grow the stream @param mid_table member-id table for non-mutable member headers, or NULL @param data sample or key data to serialize @param ops marshalling metadata for @p data @param bo byte order selector @returns pointer to the next operation on success, NULL on failure