pub unsafe extern "C" fn ddsrt_chh_remove(
rt: *mut ddsrt_chh,
keyobject: *const c_void,
) -> boolExpand description
@brief Concurrent version of @ref ddsrt_hh_remove
It can work in parallel to @ref ddsrt_chh_lookup, but in that case the looked up element may not be part of the hash table anymore by the time the caller of @ref ddsrt_chh_lookup accesses the element.
@param[in,out] rt the hash table @param[in] keyobject user data to remove @return false iff key not present @see ddsrt_chh_add