pub unsafe extern "C" fn ddsrt_gethostname(
hostname: *mut c_char,
buffersize: usize,
) -> dds_return_tExpand description
@brief Get the hostname
The buffer needs to be large enough to hold the name including null terminator. On success, the buffer will include the null terminator.
@param[out] hostname a buffer to copy the name into @param[in] buffersize the space (in bytes) that may be used @return a DDS_RETCODE (OK, ERROR, NOT_ENOUGH_SPACE)