pub unsafe extern "C" fn ddsrt_select(
nfds: i32,
readfds: *mut fd_set,
writefds: *mut fd_set,
errorfds: *mut fd_set,
reltime: dds_duration_t,
) -> dds_return_tExpand description
@brief Monitor multiple sockets, waiting until one or more become ready.
@param[in] nfds Highest-numbered file descriptor in any of the sets. @param[in] readfds Set of sockets to monitor for read ready status. @param[in] writefds Set of sockets to monitor for write ready status. @param[in] errorfds Set of sockets to monitor for exceptional conditions. @param[in] reltime Interval to block for sockets to become ready.
@returns The number of sockets ready in the sets or a return code.