pub unsafe extern "C" fn ddsrt_thread_getname(
name: *mut c_char,
size: usize,
) -> usizeExpand description
@brief Get name of current thread.
@param[in] name Buffer where the name is copied to. @param[in] size Number of bytes available in the buffer.
@returns The number of bytes (excluding the null terminating bytes) that are written. If the buffer is not sufficiently large enough, the name is truncated and the number of bytes that would have been written is returned.