pub unsafe extern "C" fn ddsrt_thread_join(
thread: ddsrt_thread_t,
thread_result: *mut u32,
) -> dds_return_tExpand description
@brief Wait for termination of the specified thread.
If the specified thread is still running, wait for its termination else return immediately. In thread_result it returns the exit status of the thread. If NULL is passed for @thread_result, no exit status is returned, but ddsrt_thread_join still waits for the thread to terminate.
@param[in] thread Id of thread to wait for. @param[out] thread_result Location where thread result is stored.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK Target thread terminated. @retval DDS_RETCODE_ERROR An error occurred while waiting for the thread to terminate.