pub unsafe extern "C" fn ddsrt_thread_list(
tids: *mut ddsrt_thread_list_id_t,
size: usize,
) -> dds_return_tExpand description
@brief Get a list of threads in the calling process
@param[out] tids Array of size elements to be filled with thread identifiers, may be NULL if size is 0 @param[in] size The size of the tids array; 0 is allowed
@returns A dds_return_t indicating the number of threads in the process or an error code on failure.
@retval > 0 Number of threads in the process, may be larger than size tids[0 .. (return - 1)] are valid @retval DDS_RETCODE_ERROR Something went wrong, contents of tids is undefined @retval DDS_RETCODE_UNSUPPORTED Not supported on the platform