ddsrt_avl_node

Struct ddsrt_avl_node 

#[repr(C)]
pub struct ddsrt_avl_node { pub cs: [*mut ddsrt_avl_node; 2], pub parent: *mut ddsrt_avl_node, pub height: c_int, }
@brief The avl node is the basic element of the avl tree structure.

To store user data in the tree, the avl node must be embedded in a user node, which is a struct containing the user data. All API calls with a node as input or output, deal with the user node. Example: @code{.c} typedef struct num_s{ // user node ddsrt_avl_node_t node; uint64_t val; // user data }num_t; @endcode

Fields

cs: [*mut ddsrt_avl_node; 2]

< contains pointers to the left and right child node

parent: *mut ddsrt_avl_node

< points to the parent node

height: c_int

< is the height of the subtree starting at this node