pub type ddsrt_avl_augment_t = Option<unsafe extern "C" fn(vnode: *mut c_void, left: *const c_void, right: *const c_void)>;Expand description
@brief User defined augment function.
If provided, it is called whenever the structure of the tree changes, or when explicitly calling @ref ddsrt_avl_augment_update. It is called for each node on the path to (and inclusive of) the root. It is intended to update user data in nodes when a change occurs in one or both child nodes, or when a the change occurs in the node itself.
Aliased Type
pub enum ddsrt_avl_augment_t {
None,
Some(unsafe extern "C" fn(*mut c_void, *const c_void, *const c_void)),
}